@@ -51,7 +51,7 @@ class OrderedObject;
  * start of list of objects that are linked together as a list.
  * @author David Sugar <dyfet@gnutelephony.org>
  */
-class __EXPORT LinkedObject : public Object
+class __EXPORT LinkedObject : public ObjectProtocol
 {
 protected:
     friend class OrderedIndex;
